stm32-metapac

Crates

git

Versions

stm32wba54ke

Flavors

Sr

Struct Sr 

#[repr(transparent)]
pub struct Sr(pub u32);
PKA status register.

Tuple Fields

0: u32

Implementations



impl Sr

pub const fn initok(&self) -> bool

PKA initialization OK This bit is asserted when PKA initialization is complete. When RNG is not able to output proper random numbers INITOK stays at 0.

pub const fn set_initok(&mut self, val: bool)

PKA initialization OK This bit is asserted when PKA initialization is complete. When RNG is not able to output proper random numbers INITOK stays at 0.

pub const fn lmf(&self) -> Lmf

Limited mode flag This bit is updated when EN bit in PKA_CR is set.

pub const fn set_lmf(&mut self, val: Lmf)

Limited mode flag This bit is updated when EN bit in PKA_CR is set.

pub const fn busy(&self) -> bool

PKA operation is in progress This bit is set to 1 whenever START bit in the PKA_CR is set. It is automatically cleared when the computation is complete, meaning that PKA RAM can be safely accessed and a new operation can be started. If PKA is started with a wrong opcode, it is busy for a couple of cycles, then it aborts automatically the operation and go back to ready (BUSY bit is set to 0).

pub const fn set_busy(&mut self, val: bool)

PKA operation is in progress This bit is set to 1 whenever START bit in the PKA_CR is set. It is automatically cleared when the computation is complete, meaning that PKA RAM can be safely accessed and a new operation can be started. If PKA is started with a wrong opcode, it is busy for a couple of cycles, then it aborts automatically the operation and go back to ready (BUSY bit is set to 0).

pub const fn procendf(&self) -> bool

PKA End of Operation flag.

pub const fn set_procendf(&mut self, val: bool)

PKA End of Operation flag.

pub const fn ramerrf(&self) -> bool

PKA RAM error flag This bit is cleared using RAMERRFC bit in PKA_CLRFR.

pub const fn set_ramerrf(&mut self, val: bool)

PKA RAM error flag This bit is cleared using RAMERRFC bit in PKA_CLRFR.

pub const fn addrerrf(&self) -> bool

Address error flag This bit is cleared using ADDRERRFC bit in PKA_CLRFR.

pub const fn set_addrerrf(&mut self, val: bool)

Address error flag This bit is cleared using ADDRERRFC bit in PKA_CLRFR.

pub const fn operrf(&self) -> bool

Operation error flag This bit is cleared using OPERRFC bit in PKA_CLRFR.

pub const fn set_operrf(&mut self, val: bool)

Operation error flag This bit is cleared using OPERRFC bit in PKA_CLRFR.